slipway.security.oidc


access-token-fieldclj

(access-token-field {:slipway.security.oidc/keys [access-token]} k)
source

check-credentialsclj

(check-credentials request-map now refresh-period-s)

Given a request-map with holding an authenticated OIDC user principal:

  • Determine the duration in seconds until the user expires
  • Attempt refresh-token redemption if user within refresh-period-s of expiry
  • Invalidate user session if user has expired Returns: true if the user has expired
Given a request-map with holding an authenticated OIDC user principal:
 - Determine the duration in seconds until the user expires
 - Attempt refresh-token redemption if user within refresh-period-s of expiry
 - Invalidate user session if user has expired
Returns: true if the user has expired
sourceraw docstring

configurationclj

(configuration {:slipway.security.oidc/keys
                  [issuer client-id client-secret authorization-endpoint
                   token-endpoint end-session-endpoint authentication-method
                   http-client scopes logout-when-id-token-is-expired?]
                :or {scopes ["profile" "email"]
                     logout-when-id-token-is-expired? false}})
source

flow-handlercljmultimethod

source

id-token-fieldclj

(id-token-field {:slipway.security.oidc/keys [id-token]} k)
source

principalclj

(principal user)
source

redeem-refresh-tokenclj

(redeem-refresh-token {:slipway.security.oidc/keys [principal]})
source

cljdoc builds & hosts documentation for Clojure/Script libraries