slipway.security.openid.user.principal


-getNameclj

(-getName this)
source

-getStateclj

(-getState this)
source

-initclj

(-init credentials user-state refresh-fns)
source

-redeemRefreshTokenclj

(-redeemRefreshToken this)
source

-toStringclj

(-toString this)
source

redeem-refresh-tokenclj

(redeem-refresh-token {:slipway.security.openid/keys [id-token response]
                       :as user-state}
                      {:keys [refresh-token-fn user-state-fn]})
source

refresh-user-stateclj

(refresh-user-state state-atom)

Refresh the user state, will return:

  • nil if no action was performed
  • map with :error key if any error occurs
  • map of refreshed user state if refresh successful The internal state atom is updated with refreshed user state on succesfull refresh only
Refresh the user state, will return:
- nil if no action was performed
- map with :error key if any error occurs
- map of refreshed user state if refresh successful
The internal state atom is updated with refreshed user state on succesfull refresh only
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries