(expires-in user)(expires-in user now)Seconds until user expiry:
Seconds until user expiry: - nil if no ::expires-at available for the user - pos? if the user has not expired - neg? or zero? if the user is expired
(roles user)Return the set of roles assigned to a user
Return the set of roles assigned to a user
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |