(base-handler {:slipway.context/keys [path null-path-info? virtual-hosts
error-handler]
:or {path "/"}})(handler server {:slipway.context/keys [ring-handler] :as opts})Request routing is handled in the following order: -> Request -> ContextHandler -> CompressionHandler (optional) -> SessionHandler (optional) -> SecurityHandler (optional) -> WebsocketHandler (optional) -> SyncHandler -> ring-handler
Request routing is handled in the following order: -> Request -> ContextHandler -> CompressionHandler (optional) -> SessionHandler (optional) -> SecurityHandler (optional) -> WebsocketHandler (optional) -> SyncHandler -> ring-handler
(wrap-security-and-session handler opts)We only wrap the session handler if you definitely have a security handler Anonymous sessions are not supported by this context handler
We only wrap the session handler if you definitely have a security handler Anonymous sessions are not supported by this context handler
(wrap-session security-handler opts)In some circumstances a server may be configured without a SessionHandler For example a stateless API with OpenID client-credentials authorization flow
In some circumstances a server may be configured without a SessionHandler For example a stateless API with OpenID client-credentials authorization flow
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |