(redeem-refresh-token {:slipway.security.openid/keys [id-token response]
:as user-state}
{:keys [refresh-token-fn user-state-fn]})(refresh-user-state state-atom)Refresh the user state, will return:
Refresh the user state, will return: - nil if no action was performed - map with :error key if any error occurs - map of refreshed user state if refresh successful The internal state atom is updated with refreshed user state on succesfull refresh only
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |