slipway.user


expired?clj

(expired? user)
(expired? user now)
source

expires-inclj

(expires-in user)
(expires-in user now)

Seconds until user expiry:

  • nil if no ::expires-at available for the user
  • pos? if the user has not expired
  • neg? or zero? if the user is expired
Seconds until user expiry:
- nil if no ::expires-at available for the user
- pos? if the user has not expired
- neg? or zero? if the user is expired
sourceraw docstring

in-role?clj

(in-role? {:slipway.user/keys [roles]} role)
source

nameclj

source

rolesclj

(roles user)

Return the set of roles assigned to a user

Return the set of roles assigned to a user
sourceraw docstring

typeclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries